/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     PROC = 258,
     FUNC_TOK = 259,
     IDEN = 260,
     SCONS = 261,
     CHILDREN = 262,
     SPOUSES = 263,
     IF = 264,
     ELSE = 265,
     ELSIF = 266,
     FAMILIES = 267,
     ICONS = 268,
     WHILE = 269,
     CALL = 270,
     FORINDISET = 271,
     FORINDI = 272,
     FORNOTES = 273,
     TRAVERSE = 274,
     FORNODES = 275,
     FORLIST_TOK = 276,
     FORFAM = 277,
     FORSOUR = 278,
     FOREVEN = 279,
     FOROTHR = 280,
     BREAK = 281,
     CONTINUE = 282,
     RETURN = 283,
     FATHERS = 284,
     MOTHERS = 285,
     PARENTS = 286,
     FCONS = 287
   };
#endif
#define PROC 258
#define FUNC_TOK 259
#define IDEN 260
#define SCONS 261
#define CHILDREN 262
#define SPOUSES 263
#define IF 264
#define ELSE 265
#define ELSIF 266
#define FAMILIES 267
#define ICONS 268
#define WHILE 269
#define CALL 270
#define FORINDISET 271
#define FORINDI 272
#define FORNOTES 273
#define TRAVERSE 274
#define FORNODES 275
#define FORLIST_TOK 276
#define FORFAM 277
#define FORSOUR 278
#define FOREVEN 279
#define FOROTHR 280
#define BREAK 281
#define CONTINUE 282
#define RETURN 283
#define FATHERS 284
#define MOTHERS 285
#define PARENTS 286
#define FCONS 287




/* Copy the first part of user declarations.  */
#line 36 "../../../src/interp/yacc.y"

/*#define YACC_C */
#include "llstdlib.h"
#include "table.h"
#include "translat.h"
#include "gedcom.h"
#include "cache.h"
#include "indiseq.h"
#include "interpi.h"
#include "liflines.h"
#include "parse.h"
#include <stdlib.h>

static PNODE this, prev;
INT Yival;
FLOAT Yfval;

static void join (PNODE list, PNODE last);
#define yyerror(msg) parse_error(pactx, msg)



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 173 "yacc.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  11
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   931

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  38
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  18
/* YYNRULES -- Number of rules. */
#define YYNRULES  57
/* YYNRULES -- Number of states. */
#define YYNSTATES  292

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   287

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      33,    34,     2,     2,    37,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    35,     2,    36,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned short yyprhs[] =
{
       0,     0,     3,     5,     8,    10,    12,    17,    22,    31,
      40,    41,    43,    45,    49,    51,    54,    67,    82,    97,
     112,   127,   140,   155,   168,   179,   190,   201,   212,   223,
     234,   247,   258,   270,   280,   287,   292,   297,   303,   305,
     306,   308,   310,   313,   322,   323,   328,   330,   336,   338,
     340,   342,   343,   345,   347,   351,   352,   355
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      39,     0,    -1,    40,    -1,    39,    40,    -1,    41,    -1,
      42,    -1,     5,    33,     5,    34,    -1,     5,    33,     6,
      34,    -1,     3,     5,    33,    43,    34,    35,    45,    36,
      -1,     4,     5,    33,    43,    34,    35,    45,    36,    -1,
      -1,    44,    -1,     5,    -1,     5,    37,    44,    -1,    46,
      -1,    45,    46,    -1,     7,    55,    33,    51,    37,     5,
      37,     5,    34,    35,    45,    36,    -1,     8,    55,    33,
      51,    37,     5,    37,     5,    37,     5,    34,    35,    45,
      36,    -1,    12,    55,    33,    51,    37,     5,    37,     5,
      37,     5,    34,    35,    45,    36,    -1,    29,    55,    33,
      51,    37,     5,    37,     5,    37,     5,    34,    35,    45,
      36,    -1,    30,    55,    33,    51,    37,     5,    37,     5,
      37,     5,    34,    35,    45,    36,    -1,    31,    55,    33,
      51,    37,     5,    37,     5,    34,    35,    45,    36,    -1,
      16,    55,    33,    51,    37,     5,    37,     5,    37,     5,
      34,    35,    45,    36,    -1,    21,    55,    33,    51,    37,
       5,    37,     5,    34,    35,    45,    36,    -1,    17,    55,
      33,     5,    37,     5,    34,    35,    45,    36,    -1,    18,
      55,    33,    51,    37,     5,    34,    35,    45,    36,    -1,
      22,    55,    33,     5,    37,     5,    34,    35,    45,    36,
      -1,    23,    55,    33,     5,    37,     5,    34,    35,    45,
      36,    -1,    24,    55,    33,     5,    37,     5,    34,    35,
      45,    36,    -1,    25,    55,    33,     5,    37,     5,    34,
      35,    45,    36,    -1,    19,    55,    33,    51,    37,     5,
      37,     5,    34,    35,    45,    36,    -1,    20,    55,    33,
      51,    37,     5,    34,    35,    45,    36,    -1,     9,    55,
      33,    51,    54,    34,    35,    45,    36,    47,    50,    -1,
      14,    55,    33,    51,    54,    34,    35,    45,    36,    -1,
      15,     5,    55,    33,    52,    34,    -1,    26,    55,    33,
      34,    -1,    27,    55,    33,    34,    -1,    28,    55,    33,
      52,    34,    -1,    51,    -1,    -1,    48,    -1,    49,    -1,
      49,    48,    -1,    11,    33,    51,    54,    34,    35,    45,
      36,    -1,    -1,    10,    35,    45,    36,    -1,     5,    -1,
       5,    55,    33,    52,    34,    -1,     6,    -1,    13,    -1,
      32,    -1,    -1,    53,    -1,    51,    -1,    51,    37,    53,
      -1,    -1,    37,    51,    -1,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,    67,    67,    68,    71,    72,    73,    79,    92,    98,
     103,   106,   110,   114,   120,   123,   128,   134,   140,   146,
     152,   158,   164,   170,   176,   182,   188,   194,   200,   206,
     212,   217,   222,   238,   243,   248,   252,   256,   260,   264,
     267,   271,   274,   279,   284,   287,   291,   296,   301,   304,
     307,   311,   314,   318,   321,   326,   329,   333
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "PROC", "FUNC_TOK", "IDEN", "SCONS", 
  "CHILDREN", "SPOUSES", "IF", "ELSE", "ELSIF", "FAMILIES", "ICONS", 
  "WHILE", "CALL", "FORINDISET", "FORINDI", "FORNOTES", "TRAVERSE", 
  "FORNODES", "FORLIST_TOK", "FORFAM", "FORSOUR", "FOREVEN", "FOROTHR", 
  "BREAK", "CONTINUE", "RETURN", "FATHERS", "MOTHERS", "PARENTS", "FCONS", 
  "'('", "')'", "'{'", "'}'", "','", "$accept", "rspec", "defn", "proc", 
  "func", "idenso", "idens", "tmplts", "tmplt", "elsifso", "elsifs", 
  "elsif", "elseo", "expr", "exprso", "exprs", "secondo", "m", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,    40,    41,   123,   125,    44
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    38,    39,    39,    40,    40,    40,    40,    41,    42,
      43,    43,    44,    44,    45,    45,    46,    46,    46,    46,
      46,    46,    46,    46,    46,    46,    46,    46,    46,    46,
      46,    46,    46,    46,    46,    46,    46,    46,    46,    47,
      47,    48,    48,    49,    50,    50,    51,    51,    51,    51,
      51,    52,    52,    53,    53,    54,    54,    55
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     1,     2,     1,     1,     4,     4,     8,     8,
       0,     1,     1,     3,     1,     2,    12,    14,    14,    14,
      14,    12,    14,    12,    10,    10,    10,    10,    10,    10,
      12,    10,    11,     9,     6,     4,     4,     5,     1,     0,
       1,     1,     2,     8,     0,     4,     1,     5,     1,     1,
       1,     0,     1,     1,     3,     0,     2,     0
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       0,     0,     0,     0,     0,     2,     4,     5,     0,     0,
       0,     1,     3,    10,    10,     0,     0,    12,     0,    11,
       0,     6,     7,     0,     0,     0,    13,     0,     0,    46,
      48,    57,    57,    57,    57,    49,    57,     0,    57,    57,
      57,    57,    57,    57,    57,    57,    57,    57,    57,    57,
      57,    57,    57,    57,    50,     0,    14,    38,     0,     0,
       0,     0,     0,     0,     0,    57,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     8,    15,     9,    51,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,    51,     0,     0,     0,    53,     0,
      52,     0,     0,    55,     0,    55,    51,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    35,    36,     0,
       0,     0,     0,     0,    47,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,    37,     0,     0,     0,    54,     0,     0,    56,
       0,     0,     0,    34,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    39,     0,    33,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,    44,    40,    41,     0,     0,    24,
      25,     0,    31,     0,    26,    27,    28,    29,     0,     0,
       0,     0,     0,     0,     0,    32,    42,     0,     0,     0,
       0,     0,     0,     0,    16,     0,    55,     0,     0,     0,
      30,    23,     0,     0,    21,     0,     0,     0,     0,     0,
       0,     0,    17,     0,    45,    18,    22,    19,    20,     0,
       0,    43
};

/* YYDEFGOTO[NTERM-NUM]. */
static const short yydefgoto[] =
{
      -1,     4,     5,     6,     7,    18,    19,    55,    56,   234,
     235,   236,   255,    57,   109,   110,   138,    59
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -109
static const short yypact[] =
{
      33,     4,    10,    -8,    30,  -109,  -109,  -109,    -6,    -4,
      13,  -109,  -109,    34,    34,     6,     7,     5,    12,  -109,
      14,  -109,  -109,    34,     9,    15,  -109,   899,   899,    18,
    -109,  -109,  -109,  -109,  -109,  -109,  -109,    40,  -109,  -109,
    -109,  -109,  -109,  -109,  -109,  -109,  -109,  -109,  -109,  -109,
    -109,  -109,  -109,  -109,  -109,    77,  -109,  -109,   109,    19,
      25,    27,    44,    45,    46,  -109,    47,    48,    54,    78,
      79,    86,    87,   110,   111,   113,   114,   115,   116,   117,
     119,   121,  -109,  -109,  -109,    11,    11,    11,    11,    11,
      11,   122,    11,    42,    11,    11,    11,    11,   105,   137,
     151,   152,   125,   126,    11,    11,    11,    11,   124,   128,
    -109,   127,   129,   130,   131,   130,    11,   134,   138,   140,
     145,   146,   147,   148,   149,   150,   153,  -109,  -109,   154,
     157,   159,   164,    11,  -109,   158,   160,    11,   155,   186,
     168,   170,   200,   201,   202,   203,   204,   205,   206,   207,
     209,   211,  -109,   212,   213,   214,  -109,   183,   184,  -109,
     188,   189,   190,  -109,   191,   193,   195,   194,   196,   197,
     208,   215,   221,   222,   198,   210,   220,   233,   238,   899,
     241,   899,   253,   224,   225,   257,   234,   265,   258,   266,
     267,   289,   287,   320,   321,   260,   296,   259,   297,   291,
     319,   899,   899,   324,   899,   331,   899,   899,   899,   899,
     329,   351,   356,   322,   384,   386,   393,  -109,   415,   323,
     355,   394,   387,   395,   419,   451,   483,   515,   416,   417,
     418,   899,   420,   428,   442,  -109,   386,   450,   452,  -109,
    -109,   899,  -109,   899,  -109,  -109,  -109,  -109,   459,   460,
     899,   547,   427,    11,   481,  -109,  -109,   482,   490,   579,
     611,   491,   513,   643,  -109,   899,   130,   899,   899,   899,
    -109,  -109,   899,   899,  -109,   675,   484,   707,   739,   771,
     803,   835,  -109,   514,  -109,  -109,  -109,  -109,  -109,   899,
     867,  -109
};

/* YYPGOTO[NTERM-NUM].  */
static const short yypgoto[] =
{
    -109,  -109,   546,  -109,  -109,   471,   534,   -28,   -27,  -109,
     344,  -109,  -109,   -84,   -90,   425,  -108,    23
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -58
static const short yytable[] =
{
      58,   108,   111,   112,   113,   114,   115,   140,   117,     8,
     119,   120,   121,   122,   129,     9,    29,    30,    15,    16,
     108,   130,   131,   132,    35,    10,   141,    13,    83,    14,
      11,    83,   108,     1,     2,     3,     1,     2,     3,    17,
      21,    22,    23,    54,    27,    65,    24,   118,    25,   108,
      28,   -57,    85,   159,    60,    61,    62,    63,    86,    64,
      87,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    88,    89,    90,
      92,    93,    29,    30,    31,    32,    33,    94,    91,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
     123,    95,    96,    82,    29,    30,    31,    32,    33,    97,
      98,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,   124,    99,   100,    84,   101,   102,   103,   104,
     105,   197,   106,   199,   107,   116,   125,   126,   276,   127,
     128,   133,   134,   157,   135,   158,   136,   137,   139,   266,
      83,   142,    83,   219,   220,   143,   222,   144,   224,   225,
     226,   227,   145,   146,   147,   148,   149,   150,   152,   160,
     151,   161,    83,    83,   153,    83,   154,    83,    83,    83,
      83,   155,   162,   251,   163,   164,   165,   166,   167,   168,
     169,   170,   171,   259,   172,   260,   173,   174,   175,   176,
     177,   178,   263,   179,    83,   181,   180,   183,   182,   184,
     186,   185,    83,    83,   187,   192,    83,   275,   195,   277,
     278,   279,   188,   196,   280,   281,   198,   193,    83,   189,
      83,    83,    83,    83,    83,   190,   191,   194,   200,   201,
     202,   290,   203,    83,    29,    30,    31,    32,    33,   204,
     205,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,   210,   206,   213,   215,    29,    30,    31,    32,
      33,   207,   208,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,   209,   211,   212,   217,    29,    30,
      31,    32,    33,   214,   216,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,   218,   231,   221,   239,
      29,    30,    31,    32,    33,   223,   228,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,   229,   232,
     230,   240,    29,    30,    31,    32,    33,   233,   237,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
     238,   248,   249,   242,    29,    30,    31,    32,    33,   241,
     243,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,   254,   250,   252,   244,    29,    30,    31,    32,
      33,   253,   265,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,   257,    20,   258,   245,    29,    30,
      31,    32,    33,   261,   262,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,   267,   268,   283,   246,
      29,    30,    31,    32,    33,   269,   272,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,   273,   289,
      12,   247,    29,    30,    31,    32,    33,    26,   156,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
     256,     0,     0,   264,    29,    30,    31,    32,    33,     0,
       0,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,     0,     0,     0,   270,    29,    30,    31,    32,
      33,     0,     0,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,     0,     0,     0,   271,    29,    30,
      31,    32,    33,     0,     0,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,     0,     0,     0,   274,
      29,    30,    31,    32,    33,     0,     0,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,     0,     0,
       0,   282,    29,    30,    31,    32,    33,     0,     0,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
       0,     0,     0,   284,    29,    30,    31,    32,    33,     0,
       0,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,     0,     0,     0,   285,    29,    30,    31,    32,
      33,     0,     0,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,     0,     0,     0,   286,    29,    30,
      31,    32,    33,     0,     0,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,     0,     0,     0,   287,
      29,    30,    31,    32,    33,     0,     0,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,     0,     0,
       0,   288,    29,    30,    31,    32,    33,     0,     0,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
       0,     0,     0,   291,    29,    30,    31,    32,    33,     0,
       0,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54
};

static const short yycheck[] =
{
      28,    85,    86,    87,    88,    89,    90,   115,    92,     5,
      94,    95,    96,    97,   104,     5,     5,     6,     5,     6,
     104,   105,   106,   107,    13,    33,   116,    33,    55,    33,
       0,    58,   116,     3,     4,     5,     3,     4,     5,     5,
      34,    34,    37,    32,    35,     5,    34,     5,    34,   133,
      35,    33,    33,   137,    31,    32,    33,    34,    33,    36,
      33,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    33,    33,    33,
      33,    33,     5,     6,     7,     8,     9,    33,    65,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
       5,    33,    33,    36,     5,     6,     7,     8,     9,    33,
      33,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,     5,    33,    33,    36,    33,    33,    33,    33,
      33,   179,    33,   181,    33,    33,     5,     5,   266,    34,
      34,    37,    34,     5,    37,     5,    37,    37,    37,   253,
     197,    37,   199,   201,   202,    37,   204,    37,   206,   207,
     208,   209,    37,    37,    37,    37,    37,    37,    34,    34,
      37,     5,   219,   220,    37,   222,    37,   224,   225,   226,
     227,    37,    34,   231,    34,     5,     5,     5,     5,     5,
       5,     5,     5,   241,     5,   243,     5,     5,     5,     5,
      37,    37,   250,    35,   251,    35,    37,    34,    37,    34,
      34,    37,   259,   260,    37,    37,   263,   265,     5,   267,
     268,   269,    34,     5,   272,   273,     5,    37,   275,    34,
     277,   278,   279,   280,   281,    34,    34,    37,     5,    35,
      35,   289,     5,   290,     5,     6,     7,     8,     9,    35,
       5,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,     5,    35,    34,    36,     5,     6,     7,     8,
       9,    35,    35,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    35,     5,     5,    36,     5,     6,
       7,     8,     9,    37,    37,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    37,    35,    34,    36,
       5,     6,     7,     8,     9,    34,    37,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    37,     5,
      34,    36,     5,     6,     7,     8,     9,    11,     5,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
       5,     5,     5,    36,     5,     6,     7,     8,     9,    35,
      35,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    10,    35,    34,    36,     5,     6,     7,     8,
       9,    33,    35,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    34,    14,    34,    36,     5,     6,
       7,     8,     9,    34,    34,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    35,    35,    34,    36,
       5,     6,     7,     8,     9,    35,    35,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    35,    35,
       4,    36,     5,     6,     7,     8,     9,    23,   133,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
     236,    -1,    -1,    36,     5,     6,     7,     8,     9,    -1,
      -1,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    -1,    -1,    -1,    36,     5,     6,     7,     8,
       9,    -1,    -1,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    -1,    -1,    -1,    36,     5,     6,
       7,     8,     9,    -1,    -1,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    -1,    -1,    -1,    36,
       5,     6,     7,     8,     9,    -1,    -1,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    -1,    -1,
      -1,    36,     5,     6,     7,     8,     9,    -1,    -1,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
      -1,    -1,    -1,    36,     5,     6,     7,     8,     9,    -1,
      -1,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    -1,    -1,    -1,    36,     5,     6,     7,     8,
       9,    -1,    -1,    12,    13,    14,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    -1,    -1,    -1,    36,     5,     6,
       7,     8,     9,    -1,    -1,    12,    13,    14,    15,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    -1,    -1,    -1,    36,
       5,     6,     7,     8,     9,    -1,    -1,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    -1,    -1,
      -1,    36,     5,     6,     7,     8,     9,    -1,    -1,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
      -1,    -1,    -1,    36,     5,     6,     7,     8,     9,    -1,
      -1,    12,    13,    14,    15,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,     3,     4,     5,    39,    40,    41,    42,     5,     5,
      33,     0,    40,    33,    33,     5,     6,     5,    43,    44,
      43,    34,    34,    37,    34,    34,    44,    35,    35,     5,
       6,     7,     8,     9,    12,    13,    14,    15,    16,    17,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      28,    29,    30,    31,    32,    45,    46,    51,    45,    55,
      55,    55,    55,    55,    55,     5,    55,    55,    55,    55,
      55,    55,    55,    55,    55,    55,    55,    55,    55,    55,
      55,    55,    36,    46,    36,    33,    33,    33,    33,    33,
      33,    55,    33,    33,    33,    33,    33,    33,    33,    33,
      33,    33,    33,    33,    33,    33,    33,    33,    51,    52,
      53,    51,    51,    51,    51,    51,    33,    51,     5,    51,
      51,    51,    51,     5,     5,     5,     5,    34,    34,    52,
      51,    51,    51,    37,    34,    37,    37,    37,    54,    37,
      54,    52,    37,    37,    37,    37,    37,    37,    37,    37,
      37,    37,    34,    37,    37,    37,    53,     5,     5,    51,
      34,     5,    34,    34,     5,     5,     5,     5,     5,     5,
       5,     5,     5,     5,     5,     5,     5,    37,    37,    35,
      37,    35,    37,    34,    34,    37,    34,    37,    34,    34,
      34,    34,    37,    37,    37,     5,     5,    45,     5,    45,
       5,    35,    35,     5,    35,     5,    35,    35,    35,    35,
       5,     5,     5,    34,    37,    36,    37,    36,    37,    45,
      45,    34,    45,    34,    45,    45,    45,    45,    37,    37,
      34,    35,     5,    11,    47,    48,    49,     5,     5,    36,
      36,    35,    36,    35,    36,    36,    36,    36,     5,     5,
      35,    45,    34,    33,    10,    50,    48,    34,    34,    45,
      45,    34,    34,    45,    36,    35,    51,    35,    35,    35,
      36,    36,    35,    35,    36,    45,    54,    45,    45,    45,
      45,    45,    36,    34,    36,    36,    36,    36,    36,    35,
      45,    36
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (&yylval, YYLEX_PARAM)
#else
# define YYLEX yylex (&yylval)
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */






/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  /* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;

  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 6:
#line 73 "../../../src/interp/yacc.y"
    {
			if (eqstr("global", (STRING) yyvsp[-3]))
				pa_handle_global((STRING) yyvsp[-1]);
				free_iden(yyvsp[-3]);
				free_iden(yyvsp[-1]);
		}
    break;

  case 7:
#line 79 "../../../src/interp/yacc.y"
    {
			if (eqstr("include", (STRING) yyvsp[-3]))
				pa_handle_include(pactx, (PNODE) yyvsp[-1]);
			if (eqstr("option", (STRING) yyvsp[-3]))
				pa_handle_option(ivalue((PNODE) yyvsp[-1]));
			if (eqstr("char_encoding", (STRING) yyvsp[-3]))
				pa_handle_char_encoding(pactx, (PNODE) yyvsp[-1]);
			if (eqstr("require", (STRING) yyvsp[-3]))
				pa_handle_require(pactx, (PNODE) yyvsp[-1]);
			free_iden(yyvsp[-3]);
		}
    break;

  case 8:
#line 92 "../../../src/interp/yacc.y"
    {
			/* consumes $2 */
			pa_handle_proc(pactx, (STRING) yyvsp[-6], (PNODE) yyvsp[-4], (PNODE) yyvsp[-1]);
		}
    break;

  case 9:
#line 98 "../../../src/interp/yacc.y"
    {
			/* consumes $2 */
			pa_handle_func(pactx, (STRING) yyvsp[-6], (PNODE) yyvsp[-4], (PNODE) yyvsp[-1]);
		}
    break;

  case 10:
#line 103 "../../../src/interp/yacc.y"
    {
			yyval = 0;
		}
    break;

  case 11:
#line 106 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 12:
#line 110 "../../../src/interp/yacc.y"
    {
			/* consumes $1 */
			yyval = iden_node(pactx, (STRING)yyvsp[0]);
		}
    break;

  case 13:
#line 114 "../../../src/interp/yacc.y"
    {
			/* consumes $1 */
			yyval = iden_node(pactx, (STRING)yyvsp[-2]);
			inext(((PNODE)yyval)) = (PNODE) yyvsp[0];
		}
    break;

  case 14:
#line 120 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 15:
#line 123 "../../../src/interp/yacc.y"
    {
			join((PNODE) yyvsp[-1], (PNODE) yyvsp[0]);
			yyval = yyvsp[-1];
		}
    break;

  case 16:
#line 129 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 */
			yyval = children_node(pactx, (PNODE)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-10];
		}
    break;

  case 17:
#line 135 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 and $10 */
			yyval = spouses_node(pactx, (PNODE)yyvsp[-10], (STRING)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-12];
		}
    break;

  case 18:
#line 141 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 and $10 */
			yyval = families_node(pactx, (PNODE)yyvsp[-10], (STRING)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-12];
		}
    break;

  case 19:
#line 147 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 and $10 */
			yyval = fathers_node(pactx, (PNODE)yyvsp[-10], (STRING)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-12];
		}
    break;

  case 20:
#line 153 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 and $10 */
			yyval = mothers_node(pactx, (PNODE)yyvsp[-10], (STRING)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-12];
		}
    break;

  case 21:
#line 159 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 */
			yyval = parents_node(pactx, (PNODE)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-10];
		}
    break;

  case 22:
#line 165 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 and $10 */
			yyval = forindiset_node(pactx, (PNODE)yyvsp[-10], (STRING)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-12];
		}
    break;

  case 23:
#line 171 "../../../src/interp/yacc.y"
    {
			/* consumes $6 and $8 */
			yyval = forlist_node(pactx, (PNODE)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-10];
		}
    break;

  case 24:
#line 177 "../../../src/interp/yacc.y"
    {
			/* consumes $4 and $6 */
			yyval = forindi_node(pactx, (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 25:
#line 183 "../../../src/interp/yacc.y"
    {
			/* consumes $6 */
			yyval = fornotes_node(pactx, (PNODE)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 26:
#line 189 "../../../src/interp/yacc.y"
    {
			/* consumes $4 and $6 */
			yyval = forfam_node(pactx, (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 27:
#line 195 "../../../src/interp/yacc.y"
    {
			/* consumes $4 and $6 */
			yyval = forsour_node(pactx, (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 28:
#line 201 "../../../src/interp/yacc.y"
    {
			/* consumes $4 and $6 */
			yyval = foreven_node(pactx, (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 29:
#line 207 "../../../src/interp/yacc.y"
    {
			/* consumes $4 and $6 */
			yyval = forothr_node(pactx, (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 30:
#line 212 "../../../src/interp/yacc.y"
    {
			/* consumes $6 */
			yyval = traverse_node(pactx, (PNODE)yyvsp[-8], (STRING)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-10];
		}
    break;

  case 31:
#line 217 "../../../src/interp/yacc.y"
    {
			/* consumes $6 */
			yyval = fornodes_node(pactx, (PNODE)yyvsp[-6], (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-8];
		}
    break;

  case 32:
#line 222 "../../../src/interp/yacc.y"
    {
			inext(((PNODE)yyvsp[-7])) = (PNODE)yyvsp[-6];
			prev = NULL;  this = (PNODE)yyvsp[-1];
			while (this) {
				prev = this;
				this = (PNODE) ielse(this);
			}
			if (prev) {
				ielse(prev) = (VPTR)yyvsp[0];
				yyval = if_node(pactx, (PNODE)yyvsp[-7], (PNODE)yyvsp[-3],
				    (PNODE)yyvsp[-1]);
			} else
				yyval = if_node(pactx, (PNODE)yyvsp[-7], (PNODE)yyvsp[-3],
				    (PNODE)yyvsp[0]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-9];
		}
    break;

  case 33:
#line 238 "../../../src/interp/yacc.y"
    {
			inext(((PNODE)yyvsp[-5])) = (PNODE)yyvsp[-4];
			yyval = while_node(pactx, (PNODE)yyvsp[-5], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-7];
		}
    break;

  case 34:
#line 243 "../../../src/interp/yacc.y"
    {
			/* consumes $2 */
			yyval = call_node(pactx, (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-3];
		}
    break;

  case 35:
#line 248 "../../../src/interp/yacc.y"
    {
			yyval = break_node(pactx);
			((PNODE)yyval)->i_line = (INT) yyvsp[-2];
		}
    break;

  case 36:
#line 252 "../../../src/interp/yacc.y"
    {
			yyval = continue_node(pactx);
			((PNODE)yyval)->i_line = (INT) yyvsp[-2];
		}
    break;

  case 37:
#line 256 "../../../src/interp/yacc.y"
    {
			yyval = return_node(pactx, (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT) yyvsp[-3];
		}
    break;

  case 38:
#line 260 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 39:
#line 264 "../../../src/interp/yacc.y"
    {
			yyval = 0;
		}
    break;

  case 40:
#line 267 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 41:
#line 271 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 42:
#line 274 "../../../src/interp/yacc.y"
    {
			ielse((PNODE)yyvsp[-1]) = (VPTR)yyvsp[0];
			yyval = yyvsp[-1];
		}
    break;

  case 43:
#line 279 "../../../src/interp/yacc.y"
    {
			inext(((PNODE)yyvsp[-5])) = (PNODE)yyvsp[-4];
			yyval = if_node(pactx, (PNODE)yyvsp[-5], (PNODE)yyvsp[-1], (PNODE)NULL);
		}
    break;

  case 44:
#line 284 "../../../src/interp/yacc.y"
    {
			yyval = 0;
		}
    break;

  case 45:
#line 287 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[-1];
		}
    break;

  case 46:
#line 291 "../../../src/interp/yacc.y"
    {
			/* consumes $1 */
			yyval = iden_node(pactx, (STRING)yyvsp[0]);
			iargs(((PNODE)yyval)) = NULL;
		}
    break;

  case 47:
#line 296 "../../../src/interp/yacc.y"
    {
			/* consumes $1 */
			yyval = func_node(pactx, (STRING)yyvsp[-4], (PNODE)yyvsp[-1]);
			((PNODE)yyval)->i_line = (INT)yyvsp[-3];
		}
    break;

  case 48:
#line 301 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 49:
#line 304 "../../../src/interp/yacc.y"
    {
			yyval = icons_node(pactx, Yival);
		}
    break;

  case 50:
#line 307 "../../../src/interp/yacc.y"
    {
			yyval = fcons_node(pactx, Yfval);
		}
    break;

  case 51:
#line 311 "../../../src/interp/yacc.y"
    {
			yyval = 0;
		}
    break;

  case 52:
#line 314 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 53:
#line 318 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 54:
#line 321 "../../../src/interp/yacc.y"
    {
			inext(((PNODE)yyvsp[-2])) = (PNODE) yyvsp[0];
			yyval = yyvsp[-2];
		}
    break;

  case 55:
#line 326 "../../../src/interp/yacc.y"
    {
			yyval = 0;
		}
    break;

  case 56:
#line 329 "../../../src/interp/yacc.y"
    {
			yyval = yyvsp[0];
		}
    break;

  case 57:
#line 333 "../../../src/interp/yacc.y"
    {
			yyval = (YYSTYPE)((PACTX)pactx)->lineno;
		}
    break;


    }

/* Line 999 of yacc.c.  */
#line 1816 "yacc.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  const char* yyprefix;
	  char *yymsg;
	  int yyx;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int yyxbegin = yyn < 0 ? -yyn : 0;

	  /* Stay within bounds of both yycheck and yytname.  */
	  int yychecklim = YYLAST - yyn;
	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
	  int yycount = 0;

	  yyprefix = ", expecting ";
	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      {
		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
		yycount += 1;
		if (yycount == 5)
		  {
		    yysize = 0;
		    break;
		  }
	      }
	  yysize += (sizeof ("syntax error, unexpected ")
		     + yystrlen (yytname[yytype]));
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yyprefix = ", expecting ";
		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			yyp = yystpcpy (yyp, yyprefix);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yyprefix = " or ";
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 337 "../../../src/interp/yacc.y"


void
join (PNODE list,
      PNODE last)
{
	PNODE prev = NULL;
	while (list) {
		prev = list;
		list = inext(list);
	}
	ASSERT(prev);
	inext(prev) = last;
}


